==> pyvispr-2024.13.tar.gz: pyvispr-2024.13/package/pyvispr/config/path.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2017
SEE COPYRIGHT NOTICE BELOW
"""

import sys as sstm
from pathlib import Path as path_t

import platformdirs as fldr
from pyvispr.constant.app import APP_NAME

CONFIG_FOLDER = fldr.user_config_path(appname=APP_NAME, ensure_exists=True)
CONFIG_FILE = CONFIG_FOLDER / "config.ini"

CATALOG_FOLDER_FACTORY = None
where = path_t(__file__).resolve(strict=True)
for path in sstm.path:
    path = path_t(path).resolve(strict=True)
    if where.is_relative_to(path):
        CATALOG_FOLDER_FACTORY = path / "catalog" / "factory"
        break
CATALOG_FOLDER = CONFIG_FOLDER / "catalog"

if not CONFIG_FILE.is_file():
    CONFIG_FILE.touch(mode=0o600, exist_ok=True)
if not CATALOG_FOLDER.is_dir():
    CATALOG_FOLDER.mkdir(mode=0o700, parents=True, exist_ok=True)

"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> pyvispr-2024.42.tar.gz: pyvispr-2024.42/package/pyvispr/config/path.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2017
SEE COPYRIGHT NOTICE BELOW
"""

from pathlib import Path as path_t

import platformdirs as fldr
from pyvispr.constant.app import APP_NAME

CONFIG_FOLDER = fldr.user_config_path(appname=APP_NAME, ensure_exists=True)
CONFIG_FILE = CONFIG_FOLDER / "config.ini"

# /!\ MAINTAIN THIS FOLLOWING DEFINITION IN SYNC WITH ACTUAL FOLDER HIERARCHY.
CATALOG_FOLDER_FACTORY = (path_t(__file__).parent / ".." / "catalog" / "factory").resolve(strict=True)
CATALOG_FOLDER = CONFIG_FOLDER / "catalog"

if not CONFIG_FILE.is_file():
    CONFIG_FILE.touch(mode=0o600, exist_ok=True)
if not CATALOG_FOLDER.is_dir():
    CATALOG_FOLDER.mkdir(mode=0o700, parents=True, exist_ok=True)

"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
